==> haskell-mwc-random-0.14.0.0-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mwc-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mwc-random
version: 0.14.0.0
id: mwc-random-0.14.0.0-2pxNHDgDQNDAJj9EQzqdx2
key: mwc-random-0.14.0.0-2pxNHDgDQNDAJj9EQzqdx2
license: BSD-3-Clause
copyright: 2009, 2010, 2011 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/mwc-random
synopsis: Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.
    .
    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.
    .
    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.
category: Math, Statistics
abi: ed9c0a9334e8f158e052d5c3d1130430
exposed: True
exposed-modules:
    System.Random.MWC System.Random.MWC.CondensedTable
    System.Random.MWC.Distributions System.Random.MWC.SeedSource
import-dirs: /usr/lib/ghc-8.6.5/site-local/mwc-random-0.14.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/mwc-random-0.14.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/mwc-random-0.14.0.0
hs-libraries: HSmwc-random-0.14.0.0-2pxNHDgDQNDAJj9EQzqdx2
depends:
    base-4.12.0.0 math-functions-0.3.1.0-GW8vg3sPECY78WvUCbZJWc
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b time-1.8.0.2
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html: /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mwc-random-0.14.0.0-31-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mwc-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mwc-random
version: 0.14.0.0
id: mwc-random-0.14.0.0-3OEYgJnrFeWFi8tMJuzC34
key: mwc-random-0.14.0.0-3OEYgJnrFeWFi8tMJuzC34
license: BSD-3-Clause
copyright: 2009, 2010, 2011 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/mwc-random
synopsis: Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.
    .
    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.
    .
    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.
category: Math, Statistics
abi: a7370406bb2e99d94d2796f612b6a084
exposed: True
exposed-modules:
    System.Random.MWC System.Random.MWC.CondensedTable
    System.Random.MWC.Distributions System.Random.MWC.SeedSource
import-dirs: /usr/lib/ghc-8.6.5/site-local/mwc-random-0.14.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/mwc-random-0.14.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/mwc-random-0.14.0.0
hs-libraries: HSmwc-random-0.14.0.0-3OEYgJnrFeWFi8tMJuzC34
depends:
    base-4.12.0.0 math-functions-0.3.2.1-KHpmsRMeLk726whakxkYZR
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b time-1.8.0.2
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html: /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
